#!/bin/sh
#
# Start the isp_media_server in the configuration for Basler daA3840-30mc
#
# (c) Basler 2020
# (c) NXP 2020-2021
#

RUNTIME_DIR="$( cd "$(dirname "$0")" >/dev/null 2>&1 ; pwd -P )"
NR_DEVICE_TREE_BASLER=$(grep basler-camera-vvcam /sys/firmware/devicetree/base/soc@0/*/i2c@*/*/compatible -l | wc -l 2> /dev/null)
DMESG_BASLER=`dmesg | grep Basler`

# check if the basler device has been enabled in the device tree
if [ $NR_DEVICE_TREE_BASLER -eq 1 ]; then

	echo "Starting isp_media_server for Single Basler daA3840-30mc"

	cd $RUNTIME_DIR
	# Default configuration for Basler daA3840-30mc: basler_4k
	# Available configurations: basler_4k, basler_1080p60, basler_4khdr, basler_1080p60hdr
	exec ./run.sh -c basler_4k -lm

elif [ $NR_DEVICE_TREE_BASLER -eq 2 ]; then

	echo "Starting isp_media_server for Dual Basler daA3840-30mc"

	cd $RUNTIME_DIR
	# Default configuration for Basler daA3840-30mc: dual_basler_1080p60
	# Available configurations: dual_basler_1080p60, dual_basler_1080p60hdr
	exec ./run.sh -c dual_basler_1080p60 -lm

elif [ ! -z "$DMESG_BASLER" ]; then

	echo "Starting isp_media_server for generic Basler"

	cd $RUNTIME_DIR
	exec ./run.sh -c basler_1080p60

else
	# no device tree found exit with code no device or address
	echo "Basler camera not found!" >&2
	exit 6
fi
